=======
Credits
=======

Development Lead
----------------

* Malte Vogl <mvogl@mpiwg-berlin.mpg.de>
* Bernardo S. Buarque <bsbuarque@mpiwg-berlin.mpg.de>

Contributors
------------

* Jascha Schmitz <jmschmitz@mpiwg-berlin.mpg.de>
